Write-Host "Find broad object fields"
rg ":\s*object\b|dict\[str,\s*object\]|list\[object\]|Any" src/accountable_record

Write-Host "Find PipelineState fields"
rg "class PipelineState|identity:|contract|source|elements:|catalog:|export|package|generated|lock" src/accountable_record

Write-Host "Find Artifact types"
rg "class .*Artifact|Artifact\b" src/accountable_record

Write-Host "Find stage validators/transforms"
rg "def validate_|def run_|PipelineState|StageResult|StageDiagnostic" src/accountable_record
